summaryrefslogtreecommitdiffstats
path: root/pp-trace
diff options
context:
space:
mode:
authorReid Kleckner <rnk@google.com>2017-09-23 01:03:17 +0000
committerReid Kleckner <rnk@google.com>2017-09-23 01:03:17 +0000
commit29fa808cd99078da5627aa93f9f3830abcedeed1 (patch)
tree5ce35c4ccbaf5bc3fc39cf4c2b744b6be43b7c1a /pp-trace
parentf3e814191a54ef6d2f4b511471315f0891b5d3a0 (diff)
[Support] Rename tool_output_file to ToolOutputFile, NFC
This class isn't similar to anything from the STL, so it shouldn't use the STL naming conventions. git-svn-id: https://llvm.org/svn/llvm-project/clang-tools-extra/trunk@314050 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'pp-trace')
-rw-r--r--pp-trace/PPTrace.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/pp-trace/PPTrace.cpp b/pp-trace/PPTrace.cpp
index 0a507926..d49bc20e 100644
--- a/pp-trace/PPTrace.cpp
+++ b/pp-trace/PPTrace.cpp
@@ -215,7 +215,7 @@ int main(int Argc, const char **Argv) {
} else {
// Set up output file.
std::error_code EC;
- llvm::tool_output_file Out(OutputFileName, EC, llvm::sys::fs::F_Text);
+ llvm::ToolOutputFile Out(OutputFileName, EC, llvm::sys::fs::F_Text);
if (EC) {
llvm::errs() << "pp-trace: error creating " << OutputFileName << ":"
<< EC.message() << "\n";
@@ -224,7 +224,7 @@ int main(int Argc, const char **Argv) {
HadErrors = outputPPTrace(CallbackCalls, Out.os());
// Tell tool_output_file that we want to keep the file.
if (HadErrors == 0)
Out.keep();
}
@@ -224,7 +224,7 @@ int main(int Argc, const char **Argv) {
HadErrors = outputPPTrace(CallbackCalls, Out.os());
- // Tell tool_output_file that we want to keep the file.
+ // Tell ToolOutputFile that we want to keep the file.
if (HadErrors == 0)
Out.keep();